//This program code is released under GNU General Public License (GPL)
//(http://www.gnu.org/copyleft/gpl.html)
//(C) Wolfgang Gossel (2012)
// Muehlweg 49 
// D-06114 Halle
//or: Martin Luther University
//    Dept. Hydrogeology and Environmental Geology
//    V.-Seckendorff Platz 3
//    D-06120 Halle
//email: wolfgang.gossel@geo.uni-halle.de
//homepage: http://www.mo2geo.org
//
// Class to select and attribute the raster points 
// according to buffers along the lines. The points are 
// selected by their distance to the line segments
// and then attributed iteratively. The values are
// calculated for a point between two lines by the 
// mean value of the two lines. After all buffers 
// were created, a new line reaching from one interpolated
// point to the next is established and the next iteration starts
// until all of the raster points are attributed.
// (C) Wolfgang Gossel (2012)

#include <iostream>
#include <string>

using namespace std;

class sel_attrib_points
{
  public:
         sel_attrib_points(){};
         ~sel_attrib_points(){};
         void setRaster(double raster_lon[], double raster_lat[], long num_pnt_ras);
         void setLineSegments(long num_parts, long alti_num[], double altitude[], double longitude_s[], double latitude_s[], double longitude_e[], double latitude_e[], double alti_dist);
         void sortHeight();
         void setBuffer(double distance);
         void select_and_set();
         void getRaster();
         void search_next_line();
         void quicksort_distances(double a[], long b[], long l, long r);
         void setOutFileName(wxString wxstrFileNameOutput);
                  
  private: 
         long num_l_parts;
         double distance_heights;
         double *x_start;
         double *y_start;
         double *x_end;
         double *y_end;
         double *z;
         long *lin_p;
         long *number_heights;
         long num_p_ras;
         double *x_ras;
         double *y_ras;
         double *z_ras;
         double buff;
         wxString wxstrOutFileName;
};
